@@ -15,7 +15,7 @@
 #  limitations under the License.
 
 
-class Dracut(object):
+class Dracut():
     IsoScanPath = "/run/initramfs/isoscan"
     IsoLive = "/run/initramfs/live"
     SquashLive = "/run/initramfs/squashfs"
